from fastapi import APIRouter, Depends
from sqlalchemy.sql import text
from sqlalchemy.orm import Session

from app.db.session import get_db

router = APIRouter()


@router.get("")
def health_check(db: Session = Depends(get_db)):
    """
    Health check endpoint to verify the API is running and has database connectivity.
    """
    try:
        # Check database connection by executing a simple query
        db.execute(text("SELECT 1"))
        db_status = "healthy"
    except Exception as e:
        db_status = f"unhealthy: {str(e)}"
    
    return {
        "status": "healthy",
        "database": db_status
    }