from typing import Optional
from pydantic import EmailStr, Field

from app.schemas.base import BaseSchema, TimestampSchema


class UserBase(BaseSchema):
    """Base schema for User data."""
    email: EmailStr
    full_name: Optional[str] = None
    is_active: bool = True


class UserCreate(UserBase):
    """Schema for creating a new user."""
    password: str = Field(..., min_length=8)


class UserUpdate(BaseSchema):
    """Schema for updating a user."""
    email: Optional[EmailStr] = None
    full_name: Optional[str] = None
    password: Optional[str] = Field(None, min_length=8)
    is_active: Optional[bool] = None


class UserInDBBase(UserBase, TimestampSchema):
    """Base schema for User in DB (with ID)."""
    id: int


class User(UserInDBBase):
    """Schema for User response."""
    pass


class UserInDB(UserInDBBase):
    """Schema for User in DB (with hashed_password)."""
    hashed_password: str